# Nostr long-form content [NIP-23](https://github.com/nostr-protocol/nips/blob/master/23.md)

https://github.com/nostr-protocol/nips/blob/master/23.md

Currently only works for a single Drupal user.

## Requirements

- PHP 8.1+ and the GMP extension - https://www.php.net/manual/en/ref.gmp.php

## How it works

Adds a 'Publish to Nostr' fieldset to node forms, protected by the
'publish to nostr network' permission. It currently assumes the content of
your post is stored in the 'body' field, but this can be overridden by a
setting.

Once the node has been sent, you can't publish it anymore. The event id is
stored in the nostr_content_nip23 table.

There's an extra permission to view debug information after trying to post to
the network.

## Configuration

Posts to the network need to be signed, so we need the public and private key
of your Nostr account and one relay.

```
// Path to Nostr public and private key files.
// Put these files somewhere outside your webroot!
// The values of the keys are the hex encoded versions, not bech32 (which
// either start with npub or nsec).
// Use https://damus.io/key/ or https://github.com/rot13maxi/key-convertr
// to convert.
$settings['nostr_public_key_file'] = '/path/to/public-key-file';
$settings['nostr_private_key_file'] = '/path/to/private-key-file';
```

```
// Nostr relay - find other relays at https://nostr.watch/relays/find.
// This relay seems to work fine. In case you are not connected with this one,
// add it to your relays so posts show up in your client as well.
$settings['nostr_relay'] = 'wss://relay.damus.io';
```

```
// Content fields - defaults to 'body'.
$settings['nostr_longform_content_field'] = ['field_markdown'];

// Other optional content type fields:
* field_image - should be a Media field using a image
* field_summary - short summary in plain text format
```

## Roadmap

* [x] Add image together with a Drupal image field from the entity
* [x] Add summary field
* [x] Support multiple relays instead of one
* [x] When published, add option to republish (kind 30023 is replaceable with the `d` identifiable tag)
* [ ] Add draft support to publish the event with kind 30024
* [ ] Add a tag with origin value (from which URL the article is published)
* [x] Add label #Drupal to each published event for discovering content published by a Drupal powered system
* [ ] Add a markdown editor which saves the output as MarkDown
* [ ] Replace media links with absolute URL's in the MarkDown content
* [ ] Generate event identifier (`nevent` bech32-encoded entity) after it's published (NIP-19)

## Related contrib modules

* [Nostr simple publish](https://www.drupal.org/project/nostr_simple_publish)
* [Nostr internet identifier NIP-05](https://www.drupal.org/project/nostr_id_nip05)
